from requests import request, Response
from urllib.parse import urlencode

class WebScrapingApiClient:
    api_url = 'https://api.webscrapingapi.com/v1'

    def __init__(self, api_key: str):
        self.api_key = api_key       
        
    def request(self, method: str, url: str, params: dict = None, data: dict = None, headers: dict = None, **kwargs) -> Response:
        if not params:
            params = {}

        params['api_key'] = self.api_key
        params['url'] = url
        
        if headers:
            params['keep_headers'] = 1
        else:
            headers = {}

        full_api_url = self.api_url + '?' + urlencode(params)

        return request(method, full_api_url, data=data, headers=headers, **kwargs)

    def get(self, url: str, params: dict = None, headers: dict = None, cookies: dict = None, **kwargs) -> Response:
        return self.request('GET', url, params=params, headers=headers, cookies=cookies, **kwargs)

    def post(self, url: str, params: dict = None, data: dict = None, headers: dict = None, cookies: dict = None, **kwargs) -> Response:
        return self.request('POST', url, params=params, data=data, headers=headers, cookies=cookies, **kwargs)


from setuptools import setup

setup(
    name='webscrapingapi',
    version=1.1,
    url='https://github.com/WebScrapingAPI/webscrapingapi-python',
    description='WebScrapingApi Python SDK',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Sorin-Gabriel Marica',
    author_email='sorin.marica@jeco.dev',
    maintainer='WebScrapingApi',
    maintainer_email='account@jeco.dev',
    license='MIT',
    packages=['WebScrapingApi'],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    python_requires='>=3.6',
    install_requires=['requests'],
)